pub struct Client { /* private fields */ }Expand description
Client for AWS Lambda Core
Client for invoking operations on AWS Lambda Core. Each operation on AWS Lambda Core is a method on this
this struct. .send() MUST be invoked on the generated operations to dispatch the request to the service.
Constructing a Client
A Config is required to construct a client. For most use cases, the aws-config
crate should be used to automatically resolve this config using
aws_config::load_from_env(), since this will resolve an SdkConfig which can be shared
across multiple different AWS SDK clients. This config resolution process can be customized
by calling aws_config::from_env() instead, which returns a ConfigLoader that uses
the builder pattern to customize the default config.
In the simplest case, creating a client looks as follows:
let config = aws_config::load_from_env().await;
let client = aws_sdk_lambdacore::Client::new(&config);Occasionally, SDKs may have additional service-specific values that can be set on the Config that
is absent from SdkConfig, or slightly different settings for a specific client may be desired.
The Builder struct implements From<&SdkConfig>, so setting these specific settings can be
done as follows:
let sdk_config = ::aws_config::load_from_env().await;
let config = aws_sdk_lambdacore::config::Builder::from(&sdk_config)
.some_service_specific_setting("value")
.build();See the aws-config docs and Config for more information on customizing configuration.
Note: Client construction is expensive due to connection thread pool initialization, and should be done once at application start-up.
Using the Client
A client has a function for every operation that can be performed by the service.
For example, the CreateNetworkConnector operation has
a Client::create_network_connector, function which returns a builder for that operation.
The fluent builder ultimately has a send() function that returns an async future that
returns a result, as illustrated below:
let result = client.create_network_connector()
.name("example")
.send()
.await;The underlying HTTP requests that get made by this can be modified with the customize_operation
function on the fluent builder. See the customize module for more
information.
Implementations
Sourceimpl Client
impl Client
Sourcepub fn create_network_connector(&self) -> CreateNetworkConnectorFluentBuilder
pub fn create_network_connector(&self) -> CreateNetworkConnectorFluentBuilder
Constructs a fluent builder for the CreateNetworkConnector operation.
- The fluent builder is configurable:
name(impl Into<String>)/set_name(Option<String>):
required: trueA unique name for the network connector within your account and Region. You can use the name to identify the connector in subsequent API calls.
configuration(NetworkConnectorConfiguration)/set_configuration(Option<NetworkConnectorConfiguration>):
required: trueThe network configuration for the connector. Specify a
VpcEgressConfigurationto enable outbound traffic routing through your VPC.operator_role(impl Into<String>)/set_operator_role(Option<String>):
required: falseThe ARN of the IAM role that Lambda assumes to manage elastic network interfaces in your VPC. This role must have permissions for
ec2:CreateNetworkInterface,ec2:DeleteNetworkInterface, and related describe operations.client_token(impl Into<String>)/set_client_token(Option<String>):
required: falseA unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you retry a request with the same client token, the API returns the existing connector without creating a duplicate.
tags(impl Into<String>, impl Into<String>)/set_tags(Option<HashMap::<String, String>>):
required: falseA map of key-value pairs to associate with the network connector for organization, cost allocation, or access control.
- On success, responds with
CreateNetworkConnectorOutputwith field(s):arn(String):The Amazon Resource Name (ARN) of the network connector.
name(String):The name of the network connector.
id(String): The unique identifier for a network connector, assigned by the service at creation timeconfiguration(Option<NetworkConnectorConfiguration>):The network configuration of the connector, including VPC subnets and security groups.
operator_role(Option<String>):The ARN of the IAM role that Lambda uses to manage the underlying ENI resources for this connector.
state(Option<NetworkConnectorState>):The current state of the network connector.
- On failure, responds with
SdkError<CreateNetworkConnectorError>
Sourceimpl Client
impl Client
Sourcepub fn delete_network_connector(&self) -> DeleteNetworkConnectorFluentBuilder
pub fn delete_network_connector(&self) -> DeleteNetworkConnectorFluentBuilder
Constructs a fluent builder for the DeleteNetworkConnector operation.
- The fluent builder is configurable:
identifier(impl Into<String>)/set_identifier(Option<String>):
required: true
A flexible identifier that accepts a network connector ID, name, or ARN
- On success, responds with
DeleteNetworkConnectorOutputwith field(s):arn(String):The Amazon Resource Name (ARN) of the network connector.
name(String):The name of the network connector.
id(String): The unique identifier for a network connector, assigned by the service at creation timeconfiguration(Option<NetworkConnectorConfiguration>):The network configuration of the connector, including VPC subnets and security groups.
operator_role(Option<String>):The ARN of the IAM role that Lambda uses to manage the underlying ENI resources for this connector.
state(Option<NetworkConnectorState>):The current state of the network connector. The State field is typically
DELETINGafter this call.
- On failure, responds with
SdkError<DeleteNetworkConnectorError>
Sourceimpl Client
impl Client
Sourcepub fn get_network_connector(&self) -> GetNetworkConnectorFluentBuilder
pub fn get_network_connector(&self) -> GetNetworkConnectorFluentBuilder
Constructs a fluent builder for the GetNetworkConnector operation.
- The fluent builder is configurable:
identifier(impl Into<String>)/set_identifier(Option<String>):
required: true
A flexible identifier that accepts a network connector ID, name, or ARN
- On success, responds with
GetNetworkConnectorOutputwith field(s):arn(String):The Amazon Resource Name (ARN) of the network connector.
name(String):The name of the network connector.
id(String): The unique identifier for a network connector, assigned by the service at creation timeversion(Option<i64>):The version number of the connector configuration, incremented on each update.
configuration(Option<NetworkConnectorConfiguration>):The network configuration of the connector, including VPC subnets and security groups.
operator_role(Option<String>):The ARN of the IAM role that Lambda uses to manage the underlying ENI resources for this connector.
state(Option<NetworkConnectorState>):The current state of the network connector.
state_reason(Option<String>):A human-readable explanation of the current state, populated when the state is
FAILEDorDELETE_FAILED.state_reason_code(Option<NetworkConnectorStateReasonCode>):A machine-readable code indicating the reason for the current state. Use this for programmatic error handling.
last_update_status(Option<NetworkConnectorLastUpdateStatus>):The status of the most recent update operation (
Successful,Failed, orInProgress).last_update_status_reason(Option<String>):A human-readable explanation of the last update status.
last_update_status_reason_code(Option<NetworkConnectorLastUpdateStatusReasonCode>):A machine-readable code indicating the reason for the last update status. Use this for programmatic error handling.
last_modified(Option<DateTime>):The date and time when the connector configuration was last modified.
- On failure, responds with
SdkError<GetNetworkConnectorError>
Sourceimpl Client
impl Client
Sourcepub fn list_network_connectors(&self) -> ListNetworkConnectorsFluentBuilder
pub fn list_network_connectors(&self) -> ListNetworkConnectorsFluentBuilder
Constructs a fluent builder for the ListNetworkConnectors operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
state(NetworkConnectorState)/set_state(Option<NetworkConnectorState>):
required: falseOptional filter to return only connectors in the specified state (for example,
ACTIVEorFAILED).marker(impl Into<String>)/set_marker(Option<String>):
required: falseThe pagination token from a previous
ListNetworkConnectorsresponse. Use this value to retrieve the next page of results.max_items(i32)/set_max_items(Option<i32>):
required: falseThe maximum number of connectors to return per page. Valid range: 1 to 100.
- On success, responds with
ListNetworkConnectorsOutputwith field(s):network_connectors(Vec::<NetworkConnectorSummary>):A list of network connector summaries for the current page of results.
next_marker(Option<String>):The pagination token to include in a subsequent request to retrieve the next page. This value is null when there are no more results.
- On failure, responds with
SdkError<ListNetworkConnectorsError>
Sourceimpl Client
impl Client
Sourcepub fn update_network_connector(&self) -> UpdateNetworkConnectorFluentBuilder
pub fn update_network_connector(&self) -> UpdateNetworkConnectorFluentBuilder
Constructs a fluent builder for the UpdateNetworkConnector operation.
- The fluent builder is configurable:
identifier(impl Into<String>)/set_identifier(Option<String>):
required: true
A flexible identifier that accepts a network connector ID, name, or ARNconfiguration(NetworkConnectorConfiguration)/set_configuration(Option<NetworkConnectorConfiguration>):
required: falseThe updated network configuration for the connector. Provide the full
VpcEgressConfigurationincluding all subnet IDs and security group IDs — this replaces the existing configuration.operator_role(impl Into<String>)/set_operator_role(Option<String>):
required: falseThe updated ARN of the IAM role that Lambda assumes to manage ENIs. Use this to change the operator role without recreating the connector.
client_token(impl Into<String>)/set_client_token(Option<String>):
required: falseA unique, case-sensitive identifier to ensure idempotency of the update request.
- On success, responds with
UpdateNetworkConnectorOutputwith field(s):arn(String):The Amazon Resource Name (ARN) of the network connector.
name(String):The name of the network connector.
id(String): The unique identifier for a network connector, assigned by the service at creation timeoperator_role(Option<String>):The ARN of the IAM role that Lambda uses to manage the underlying ENI resources for this connector.
configuration(Option<NetworkConnectorConfiguration>):The network configuration of the connector, including VPC subnets and security groups.
state(Option<NetworkConnectorState>):The current state of the network connector.
last_update_status(Option<NetworkConnectorLastUpdateStatus>):The status of this update operation (typically
InProgressimmediately after the call).last_update_status_reason(Option<String>):A human-readable explanation of the update status.
last_modified(Option<DateTime>):The timestamp of this update.
- On failure, responds with
SdkError<UpdateNetworkConnectorError>
Sourceimpl Client
impl Client
Sourcepub fn from_conf(conf: Config) -> Self
pub fn from_conf(conf: Config) -> Self
Creates a new client from the service Config.
Panics
This method will panic in the following cases:
- Retries or timeouts are enabled without a
sleep_implconfigured. - Identity caching is enabled without a
sleep_implandtime_sourceconfigured. - No
behavior_versionis provided.
The panic message for each of these will have instructions on how to resolve them.
Sourceimpl Client
impl Client
Sourcepub fn new(sdk_config: &SdkConfig) -> Self
pub fn new(sdk_config: &SdkConfig) -> Self
Creates a new client from an SDK Config.
Panics
- This method will panic if the
sdk_configis missing an async sleep implementation. If you experience this panic, set thesleep_implon the Config passed into this function to fix it. - This method will panic if the
sdk_configis missing an HTTP connector. If you experience this panic, set thehttp_connectoron the Config passed into this function to fix it. - This method will panic if no
BehaviorVersionis provided. If you experience this panic, setbehavior_versionon the Config or enable thebehavior-version-latestCargo feature.